@@ -1,32 +1,32 @@
 class save:
-    def SaveInt(self, name : str, tosave : int):
+    def SaveInt(name : str, tosave : int):
         output = open(f'{name}.txt', 'w')
         output.write(str(tosave))
         output.close()
     
-    def GetInt(self, name : str):
+    def GetInt(name : str):
         inp = open(f'{name}.txt', 'r')
         get = int(inp.read())
         inp.close()
         return get
     
-    def SetFloat(self, name : str, tosave : float):
+    def SetFloat(name : str, tosave : float):
         output = open(f'{name}.txt', 'w')
         output.write(str(tosave))
         output.close()
     
-    def GetFloat(self, name : str):
+    def GetFloat(name : str):
         inp = open(f'{name}.txt', 'r')
         get = float(inp.read())
         inp.close()
         return get
     
-    def SetStr(self, name : str, tosave : str):
+    def SetStr(name : str, tosave : str):
         output = open(f'{name}.txt', 'w')
         output.write(tosave)
         output.close()
     
-    def GetStr(self, name : str):
+    def GetStr(name : str):
         inp = open(f'{name}.txt', 'r')
         get = inp.read()
         inp.close()
